# SSO Configuration Process
### On this page
  * [Before You Start](https://help.sap.com/docs/leanix/ea/sso-configuration-process#before-you-start)
  * [Step 1: Starting SSO Authentication Setup](https://help.sap.com/docs/leanix/ea/sso-configuration-process#step-1:-starting-sso-authentication-setup)
  * [Step 2: Add a New Identity Provider](https://help.sap.com/docs/leanix/ea/sso-configuration-process#step-2:-add-a-new-identity-provider)
  * [Step 3: Test the Identity Provider Configuration](https://help.sap.com/docs/leanix/ea/sso-configuration-process#step-3:-test-the-identity-provider-configuration)
  * [Step 4: Activate an Identity Provider](https://help.sap.com/docs/leanix/ea/sso-configuration-process#step-4:-activate-an-identity-provider)
  * [FAQ](https://help.sap.com/docs/leanix/ea/sso-configuration-process#faq)


The self-service process of setting up SSO ensures a seamless integration with your chosen identity provider (IdP). You'll configure the SSO connection first, test the setup, and then activate. This ensures a flexible, zero-disruption deployment for different IdPs for different workspaces.
The SSO configuration options accommodate your existing infrastructure:
  * SAML metadata provisioning: Choose between dynamic URL-based synchronization for automatic updates or on-demand file uploads for controlled user data synchronization
